negativeButtonBackgroundColor property
The background color for the negative button.
If not provided, it defaults to the background color of the current theme.
Implementation
final Color? negativeButtonBackgroundColor;
The background color for the negative button.
If not provided, it defaults to the background color of the current theme.
final Color? negativeButtonBackgroundColor;