negativeButtonStyle property
The style for the negative button text.
If not provided, it defaults to the medium-sized title text style from the current theme with the primary color.
Implementation
final TextStyle? negativeButtonStyle;
The style for the negative button text.
If not provided, it defaults to the medium-sized title text style from the current theme with the primary color.
final TextStyle? negativeButtonStyle;