positiveButtonBackgroundColor property
The background color for the positive button.
If not provided, it defaults to the primary color of the current theme.
Implementation
final Color? positiveButtonBackgroundColor;
The background color for the positive button.
If not provided, it defaults to the primary color of the current theme.
final Color? positiveButtonBackgroundColor;