positiveButtonWidget property

Widget? positiveButtonWidget
final

The (optional) custom widget for the positive button.

If provided, it will be used as the positive button instead of the default button created from positiveButtonName.

Implementation

final Widget? positiveButtonWidget;