initialSelectedItems property
The initial list of items to be selected when the dialog is displayed.
Implementation
final List<T>? initialSelectedItems;
The initial list of items to be selected when the dialog is displayed.
final List<T>? initialSelectedItems;