itemBuilder property
A builder function that returns a widget to display each item in the list.
The builder takes the current BuildContext and the item value.
Implementation
final Widget Function(BuildContext context, T value) itemBuilder;
A builder function that returns a widget to display each item in the list.
The builder takes the current BuildContext and the item value.
final Widget Function(BuildContext context, T value) itemBuilder;