selectedTextBuilder property
A builder function that returns a widget to display the count of selected items.
The builder takes a list of selected items and returns a widget.
Implementation
final Widget Function(List<T>? value)? selectedTextBuilder;
A builder function that returns a widget to display the count of selected items.
The builder takes a list of selected items and returns a widget.
final Widget Function(List<T>? value)? selectedTextBuilder;