LazySingleValuePickerDialog<T> class

A dialog that allows users to pick a single value from a future list of items.

Constructors

LazySingleValuePickerDialog({String? title, Widget? titleWidget, TextStyle? titleStyle, Color? titleBackgroundColor, required Future<List<T>?> asyncItems(), required Widget itemBuilder(BuildContext context, T value, int index), DialogButton? dialogButton, bool barrierDismissible = true, bool showCloseIcon = false, double elevation = 10.0, double? dialogWidth, double? dialogHeight, double titleHeight = 60.0, double dialogBorderRadius = 4.0, String? loadingMessage, LoadingDialog? loadingDialog})
Creates a LazySingleValuePickerDialog.

Properties

asyncItems Future<List<T>?> Function()
A function that asynchronously fetches a list of items to be displayed in the dialog.
final
barrierDismissible bool
Whether the dialog can be dismissed by tapping outside the dialog.
final
dialogBorderRadius double
The border radius of the dialog.
final
dialogButton DialogButton?
Custom buttons to be displayed in the dialog.
final
dialogHeight double?
The height of the dialog.
final
dialogWidth double?
The width of the dialog.
final
elevation double
The elevation of the dialog.
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(BuildContext context, T value, int index)
A builder function that returns a widget to display each item in the list.
final
loadingDialog LoadingDialog?
Custom loading dialog to be displayed while fetching items.
final
loadingMessage String?
Message to be displayed during the loading of items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseIcon bool
Whether to show a close icon in the title bar.
final
title String?
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
final
titleBackgroundColor Color?
The background color for the title bar of the dialog.
final
titleHeight double
The height of the title bar.
final
titleStyle TextStyle?
The style to use for the title text.
final
titleWidget Widget?
Widget representing the title. If provided, title, titleBackgroundColor, showCloseIcon, and titleStyle should not be provided.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) Future<T?>
Displays the dialog and returns the selected item.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited