loadingMessage property
Message to be displayed during the loading of items.
If loadingDialog is provided, this message is ignored.
Implementation
final String? loadingMessage;
Message to be displayed during the loading of items.
If loadingDialog is provided, this message is ignored.
final String? loadingMessage;