title property

String? title
final

The (optional) title of the dialog is displayed in a large font at the top of the dialog.

Typically a String or a widget representing the title.

Implementation

final String? title;