LoadingDialog class

A simple loading dialog that can display a loading indicator and an optional message.

Constructors

LoadingDialog({String? message, TextStyle? messageStyle, Widget? messageWidget, Color? progressbarColor, Widget? progressbarWidget, bool barrierDismissible = false, double elevation = 10.0, double? dialogHeight, double? dialogWidth, double dialogBorderRadius = 4.0})
Creates a LoadingDialog instance with the specified parameters.

Properties

barrierDismissible bool
Whether the dialog can be dismissed by tapping outside.
final
dialogBorderRadius double
The border radius of the dialog.
final
dialogHeight double?
The height of the dialog.
final
dialogWidth double?
The width of the dialog.
final
elevation double
The elevation of the dialog.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
The (optional) message to be displayed below the loading indicator.
final
messageStyle TextStyle?
The style for the message text.
final
messageWidget Widget?
The (optional) custom widget for the message.
final
progressbarColor Color?
The color for the loading indicator.
final
progressbarWidget Widget?
The (optional) custom widget for the loading indicator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismiss(BuildContext context) → dynamic
Dismisses the loading dialog.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) → dynamic
Displays the loading dialog and returns a Future that resolves when the dialog is dismissed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited