LoadingDialog constructor

LoadingDialog({
  1. String? message,
  2. TextStyle? messageStyle,
  3. Widget? messageWidget,
  4. Color? progressbarColor,
  5. Widget? progressbarWidget,
  6. bool barrierDismissible = false,
  7. double elevation = 10.0,
  8. double? dialogHeight,
  9. double? dialogWidth,
  10. double dialogBorderRadius = 4.0,
})

Creates a LoadingDialog instance with the specified parameters.

This constructor allows you to create a new LoadingDialog instance with the optional parameters. You can customize the appearance of the loading dialog by providing values for message, messageStyle, messageWidget, progressbarColor, progressbarWidget, barrierDismissible, elevation, dialogWidth, dialogHeight, and dialogBorderRadius.

Example:

var loadingDialog = LoadingDialog(
  message: 'Loading...',
  // ... other parameters ...
);

Implementation

LoadingDialog({
  this.message,
  this.messageStyle,
  this.messageWidget,
  this.progressbarColor,
  this.progressbarWidget,
  this.barrierDismissible = false,
  this.elevation = 10.0,
  this.dialogHeight,
  this.dialogWidth,
  this.dialogBorderRadius = 4.0,
});