dialogBorderRadius property
The border radius of the dialog.
This parameter allows you to specify the corner radius of the dialog box.
Implementation
final double dialogBorderRadius;
The border radius of the dialog.
This parameter allows you to specify the corner radius of the dialog box.
final double dialogBorderRadius;