elevation property
The elevation of the dialog.
This parameter determines the shadow depth of the dialog.
Implementation
final double elevation;
The elevation of the dialog.
This parameter determines the shadow depth of the dialog.
final double elevation;