messageStyle property
The style for the message text.
If not provided, the default style is used based on the current theme.
Implementation
final TextStyle? messageStyle;
The style for the message text.
If not provided, the default style is used based on the current theme.
final TextStyle? messageStyle;