messageWidget property

Widget? messageWidget
final

The (optional) custom widget for the message.

If provided, it will be used as the message instead of the default text created from message.

Implementation

final Widget? messageWidget;