progressbarColor property
The color for the loading indicator.
If not provided, it defaults to the primary color of the current theme.
Implementation
final Color? progressbarColor;
The color for the loading indicator.
If not provided, it defaults to the primary color of the current theme.
final Color? progressbarColor;