progressbarWidget property
The (optional) custom widget for the loading indicator.
If provided, it will be used as the loading indicator instead of the default CircularProgressIndicator.
Implementation
final Widget? progressbarWidget;
The (optional) custom widget for the loading indicator.
If provided, it will be used as the loading indicator instead of the default CircularProgressIndicator.
final Widget? progressbarWidget;