initiallyMultiSelectAllItems property
If true, initially selects all items when the dialog is opened.
Implementation
final bool initiallyMultiSelectAllItems;
If true, initially selects all items when the dialog is opened.
final bool initiallyMultiSelectAllItems;