selectedItemBuilder property
(Optional) A callback function that defines how selected items should be displayed differently.
Implementation
final Widget Function(BuildContext context, T value, int index)?
selectedItemBuilder;
(Optional) A callback function that defines how selected items should be displayed differently.
final Widget Function(BuildContext context, T value, int index)?
selectedItemBuilder;