selectedTextStyle property
(Optional) Style for the text displaying the number of selected items.
Implementation
final TextStyle? selectedTextStyle;
(Optional) Style for the text displaying the number of selected items.
final TextStyle? selectedTextStyle;