PrimaryDialog<T> class

A customizable dialog that can display a title, description, body, and buttons.

Constructors

PrimaryDialog({required String title, Key? key, TextStyle? titleStyle, Color? titleBackgroundColor, Widget? titleWidget, String? description, TextStyle? descriptionStyle, Widget? body, ScrollPhysics bodyScrollPhysics = const AlwaysScrollableScrollPhysics(), DialogButton? dialogButton, bool barrierDismissible = true, double elevation = 10.0, double? dialogWidth, double? dialogHeight, double? titleHeight = 60.0, double dialogBorderRadius = 4.0})
Creates a PrimaryDialog instance with the specified parameters.

Properties

barrierDismissible bool
Whether the dialog can be dismissed by tapping outside.
final
body Widget?
The widget representing the body of the dialog.
final
bodyScrollPhysics ScrollPhysics
The scroll physics for the body content.
final
description String?
The (optional) description text to be displayed in the dialog.
final
descriptionStyle TextStyle?
The style for the description text.
final
dialogBorderRadius double
The border radius of the dialog.
final
dialogButton DialogButton?
An instance of DialogButton representing positive and negative buttons.
final
dialogHeight double?
The height of the dialog.
final
dialogWidth double?
The width of the dialog.
final
elevation double
The elevation of the dialog.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The (required) title of the dialog is displayed in a large font at the top of the dialog.
final
titleBackgroundColor Color?
The background color for the title area.
final
titleHeight double?
The height of the title area.
final
titleStyle TextStyle?
The style for the title text.
final
titleWidget Widget?
the widget for the title
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show(BuildContext context) Future<T?>
Displays the dialog and returns a Future that resolves when the dialog is dismissed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited