barrierDismissible property
Whether the dialog can be dismissed by tapping outside.
If set to true (default), tapping outside the dialog will dismiss it.
Implementation
final bool barrierDismissible;
Whether the dialog can be dismissed by tapping outside.
If set to true (default), tapping outside the dialog will dismiss it.
final bool barrierDismissible;