body property
The widget representing the body of the dialog.
This parameter allows you to include a custom widget as the main content of the dialog. Note that either description or body can be provided, but not both.
Implementation
final Widget? body;