bodyScrollPhysics property

ScrollPhysics bodyScrollPhysics
final

The scroll physics for the body content.

This parameter allows you to customize the scroll physics for the body content, enabling or disabling scrolling as needed.

Implementation

final ScrollPhysics bodyScrollPhysics;