description property

String? description
final

The (optional) description text to be displayed in the dialog.

This parameter allows you to provide additional information or context related to the title. Note that either description or body can be provided, but not both.

Implementation

final String? description;