descriptionStyle property
The style for the description text.
If not provided, the default style is used based on the current theme.
Implementation
final TextStyle? descriptionStyle;
The style for the description text.
If not provided, the default style is used based on the current theme.
final TextStyle? descriptionStyle;