dialogButton property
An instance of DialogButton representing positive and negative buttons.
This parameter allows you to define custom buttons for user interaction.
Implementation
final DialogButton? dialogButton;
An instance of DialogButton representing positive and negative buttons.
This parameter allows you to define custom buttons for user interaction.
final DialogButton? dialogButton;