titleBackgroundColor property
The background color for the title area.
If not provided, the default color is based on the primary color of the current theme.
Implementation
final Color? titleBackgroundColor;
The background color for the title area.
If not provided, the default color is based on the primary color of the current theme.
final Color? titleBackgroundColor;