titleHeight property
The height of the title area.
This parameter allows you to customize the height of the title area.
Implementation
final double? titleHeight;
The height of the title area.
This parameter allows you to customize the height of the title area.
final double? titleHeight;