titleStyle property
The style for the title text.
If not provided, the default style is used based on the current theme.
Implementation
final TextStyle? titleStyle;
The style for the title text.
If not provided, the default style is used based on the current theme.
final TextStyle? titleStyle;