barrierDismissible property
If true, allows dismissing the dialog by tapping outside the content area.
Implementation
final bool barrierDismissible;
If true, allows dismissing the dialog by tapping outside the content area.
final bool barrierDismissible;