itemBuilder property
A callback function that defines how each item should be displayed in the list.
Implementation
final Widget Function(BuildContext context, T value, int index) itemBuilder;
A callback function that defines how each item should be displayed in the list.
final Widget Function(BuildContext context, T value, int index) itemBuilder;