context property
The build context for which the buttons are created.
This is required to access the current theme and context-specific resources for button styling.
Implementation
final BuildContext context;
The build context for which the buttons are created.
This is required to access the current theme and context-specific resources for button styling.
final BuildContext context;