negativeButtonWidget property
The (optional) custom widget for the negative button.
If provided, it will be used as the negative button instead of the default button created from negativeButtonName.
Implementation
final Widget? negativeButtonWidget;
The (optional) custom widget for the negative button.
If provided, it will be used as the negative button instead of the default button created from negativeButtonName.
final Widget? negativeButtonWidget;