positiveButtonWidget property
The (optional) custom widget for the positive button.
If provided, it will be used as the positive button instead of the default button created from positiveButtonName.
Implementation
final Widget? positiveButtonWidget;
The (optional) custom widget for the positive button.
If provided, it will be used as the positive button instead of the default button created from positiveButtonName.
final Widget? positiveButtonWidget;