LazyMultiValuePickerDialog<T> class
A dialog that allows users to pick multiple values from a list of items.
Constructors
-
LazyMultiValuePickerDialog({String? title, Widget? titleWidget, TextStyle? titleStyle, Color? titleBackgroundColor, required Future<
List< asyncItems(), required Widget itemBuilder(BuildContext context, T value, int index), Widget selectedItemBuilder(BuildContext context, T value, int index)?, List<T> ?>T> ? initialSelectedItems, DialogButton? dialogButton, bool initiallyMultiSelectAllItems = false, MultiDialogSelectionType selectionType = MultiDialogSelectionType.checkboxTap, double elevation = 10.0, double? dialogWidth, double? dialogHeight, double titleHeight = 60.0, double dialogBorderRadius = 4.0, bool showSelectedTextWidget = true, TextStyle? selectedTextStyle, Widget selectedTextBuilder(List<T> ? value)?, String? loadingMessage, LoadingDialog? loadingDialog}) - Creates a LazyMultiValuePickerDialog.
Properties
-
asyncItems
→ Future<
List< Function()T> ?> -
A function that asynchronously fetches a list of items to be displayed in the dialog.
final
- dialogBorderRadius → double
-
The border radius of the dialog.
final
- dialogButton → DialogButton?
-
Custom buttons to be displayed in the dialog.
final
- dialogHeight → double?
-
The height of the dialog.
final
- dialogWidth → double?
-
The width of the dialog.
final
- elevation → double
-
The elevation of the dialog.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initiallyMultiSelectAllItems → bool
-
Whether to initially select all items in the list.
final
-
initialSelectedItems
→ List<
T> ? -
The initial list of items to be selected when the dialog is displayed.
final
- itemBuilder → Widget Function(BuildContext context, T value, int index)
-
A builder function that returns a widget to display each item in the list.
final
- loadingDialog → LoadingDialog?
-
Custom loading dialog to be displayed while fetching items.
final
- loadingMessage → String?
-
Message to be displayed during the loading of items.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedItemBuilder → Widget Function(BuildContext context, T value, int index)?
-
A builder function that returns a widget to display the selected item.
final
-
selectedTextBuilder
→ Widget Function(List<
T> ? value)? -
A builder function that returns a widget to display the count of selected items.
final
- selectedTextStyle → TextStyle?
-
The style of the widget displaying the count of selected items.
final
- selectionType → MultiDialogSelectionType
-
The selection type for the dialog.
final
- showSelectedTextWidget → bool
-
Whether to show a widget displaying the count of selected items.
final
- title → String?
-
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
final
- titleBackgroundColor → Color?
-
The background color for the title bar of the dialog.
final
- titleHeight → double
-
The height of the title bar.
final
- titleStyle → TextStyle?
-
The style to use for the title text.
final
- titleWidget → Widget?
-
Widget representing the title. If provided, title, titleBackgroundColor,
showCloseIcon, and titleStyle should not be provided.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
BuildContext context) → Future< List< T> ?> - Displays the dialog and returns the selected items.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited