title property
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
Typically a String or a widget representing the title.
Implementation
final String? title;
The (optional) title of the dialog is displayed in a large font at the top of the dialog.
Typically a String or a widget representing the title.
final String? title;