message property
The (optional) message to be displayed below the loading indicator.
This parameter allows you to provide additional information or context while the loading indicator is being displayed.
Implementation
final String? message;
The (optional) message to be displayed below the loading indicator.
This parameter allows you to provide additional information or context while the loading indicator is being displayed.
final String? message;