bodyScrollPhysics property
The scroll physics for the body content.
This parameter allows you to customize the scroll physics for the body content, enabling or disabling scrolling as needed.
Implementation
final ScrollPhysics bodyScrollPhysics;
The scroll physics for the body content.
This parameter allows you to customize the scroll physics for the body content, enabling or disabling scrolling as needed.
final ScrollPhysics bodyScrollPhysics;