title property
The (required) title of the dialog is displayed in a large font at the top of the dialog.
This parameter expects a String that represents the main heading or title for the dialog. It is a required parameter, and the provided title will be prominently displayed at the top of the dialog box.
Implementation
final String title;